@@ -2,7 +2,7 @@ package SOAP::WSDL::Operation;
 use strict;
 use warnings;
 use Class::Std::Storable;
-use base qw/SOAP::WSDL::Base/;
+use base qw(SOAP::WSDL::Base);
 
 my %operation_of :ATTR(:name<operation> :default<()>);
 my %input_of :ATTR(:name<input> :default<[]>);
