@@ -2,13 +2,6 @@ package SOAP::WSDL::XSD::Typelib::Builtin::NOTATION;
 use strict;
 use warnings;
 
-my %length_of           :ATTR(:name<length> :default<()>);
-my %minLength_of        :ATTR(:name<minLength> :default<()>);
-my %maxLength_of        :ATTR(:name<maxLength> :default<()>);
-my %pattern_of          :ATTR(:name<pattern> :default<()>);
-my %enumeration_of      :ATTR(:name<enumeration> :default<()>);
-my %whiteSpace_of       :ATTR(:name<whiteSpace> :default<()>);
-
 # Speed up. Class::Std::new is slow - and we don't need it's functionality...
 BEGIN {
     use Class::Std::Storable;
@@ -17,9 +10,9 @@ BEGIN {
     no warnings qw(redefine);
     no strict qw(refs);
 
-    # Yes, I know it's ugly - but this is the fastest constructor to write 
+    # Yes, I know it's ugly - but this is the fastest constructor to write
     # for Class::Std-Style inside out objects..
-    *{ __PACKAGE__ . '::new' } = sub {   
+    *{ __PACKAGE__ . '::new' } = sub {
         my $self = bless \do { my $foo } , shift;
         if (@_) {
             $self->set_value( $_[0]->{ value } )
