@@ -10,9 +10,9 @@ BEGIN {
     no warnings qw(redefine);
     no strict qw(refs);
 
-    # Yes, I know it's ugly - but this is the fastest constructor to write 
+    # Yes, I know it's ugly - but this is the fastest constructor to write
     # for Class::Std-Style inside out objects..
-    *{ __PACKAGE__ . '::new' } = sub {   
+    *{ __PACKAGE__ . '::new' } = sub {
         my $self = bless \do { my $foo } , shift;
         if (@_) {
             $self->set_value( $_[0]->{ value } )
@@ -23,4 +23,11 @@ BEGIN {
 
 };
 
+# replace all \t, \r, \n by \s
+sub set_value {
+    my $value = $_[1];
+    $value =~ s{ [\r\n\t] }{ }xmsg if defined($value);
+    $_[0]->SUPER::set_value($value);
+}
+
 1;
